@@ -23,8 +23,7 @@ class AvailableAttrsTransformer(BaseRenameTransformer):
     rename_to = "functools.WRAPPER_ASSIGNMENTS"
 
     def leave_Call(self, original_node: Call, updated_node: Call) -> BaseExpression:
-        if self.is_imported_with_old_name and m.matches(
-            updated_node, m.Call(func=m.Name(self.old_name))
-        ):
+        matcher = self.name_matcher
+        if m.matches(updated_node, m.Call(func=matcher)):
             return Name(self.new_name)
         return super().leave_Call(original_node, updated_node)
